/*
Copyright 2019 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package fi

import "k8s.io/kops/pkg/wellknownservices"

// HasAddress is implemented by elastic/floating IP addresses in order to include
// relevant dynamically allocated addresses in the api-server's server TLS certificate.
type HasAddress interface {
	Task[CloudupSubContext]

	// GetWellKnownServices returns the services that are behind this address.
	GetWellKnownServices() []wellknownservices.WellKnownService

	// FindIPAddress returns the address associated with the implementor.  If there is no address, returns (nil, nil).
	FindAddresses(context *CloudupContext) ([]string, error)
}
